'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _colors = require('material-ui/colors');

var _Form = require('material-ui/Form');

var _Button = require('material-ui/Button');

var _Button2 = _interopRequireDefault(_Button);

var _FileUpload = require('material-ui-icons/FileUpload');

var _FileUpload2 = _interopRequireDefault(_FileUpload);

var _Typography = require('material-ui/Typography');

var _Typography2 = _interopRequireDefault(_Typography);

var _reactDropzone = require('react-dropzone');

var _reactDropzone2 = _interopRequireDefault(_reactDropzone);

var _FileGrid = require('../../components/FileGrid');

var _FileGrid2 = _interopRequireDefault(_FileGrid);

var _arrayUtils = require('../../utils/arrayUtils');

var _upload = require('../../utils/upload');

var _upload2 = _interopRequireDefault(_upload);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var convertFilesUploadToFormDinamicoFiles = function convertFilesUploadToFormDinamicoFiles(files) {
    return files.map(function (file) {
        file.length = file.size;
        file.link = file.preview;

        return file;
    });
};

var MultipleUploadWidget = function (_Component) {
    _inherits(MultipleUploadWidget, _Component);

    function MultipleUploadWidget() {
        var _temp, _this, _ret;

        _classCallCheck(this, MultipleUploadWidget);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
            accepted: [].concat(_this.props.formData),
            loading: false,
            error: false
        }, _this.handleUploadFiles = function (accepted, rejected) {
            var onChange = _this.props.onChange;

            var config = _this.getUploadConfig();
            var originalAcceptedFiles = [].concat(_this.state.accepted);

            _this.setState(function (state) {
                return {
                    accepted: [].concat(originalAcceptedFiles, convertFilesUploadToFormDinamicoFiles(accepted)),
                    loading: true
                };
            });

            var promises = accepted.map(function (acceptedFile) {
                return (0, _upload2.default)(config, acceptedFile);
            });

            Promise.all(promises).then(function (values) {
                var allFiles = [].concat(originalAcceptedFiles, values).filter(function (elem, pos, arr) {
                    return arr.indexOf(elem) === pos;
                });

                _this.setState(function () {
                    return {
                        accepted: allFiles,
                        loading: false,
                        error: false
                    };
                });

                onChange(allFiles);
            }, function (error) {
                console.error('Erro ao fazer o upload', error);
                _this.setState({
                    error: error,
                    accepted: originalAcceptedFiles,
                    loading: false
                });
            });
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    MultipleUploadWidget.prototype.createHandleDeleteClick = function createHandleDeleteClick() {
        var _this2 = this;

        var onChange = this.props.onChange;


        return function (file, index) {
            _this2.setState(function (state) {
                var array = (0, _arrayUtils.removeItemArray)(state.accepted, index);

                onChange(array);
                return { accepted: array };
            });
        };
    };

    MultipleUploadWidget.prototype.getUploadConfig = function getUploadConfig() {
        var uiSchema = this.props.uiSchema;


        return uiSchema['ui:options'].upload;
    };

    MultipleUploadWidget.prototype.renderFileList = function renderFileList() {
        var accepted = this.state.accepted;


        return _react2.default.createElement(
            'div',
            { style: { marginTop: '15px' } },
            _react2.default.createElement(_FileGrid2.default, {
                files: accepted,
                onDeleteClick: this.createHandleDeleteClick()
            })
        );
    };

    MultipleUploadWidget.prototype.renderError = function renderError() {
        return _react2.default.createElement(
            'p',
            { style: { margin: '15px 0 0' } },
            _react2.default.createElement(
                _Typography2.default,
                {
                    component: 'span',
                    style: { color: _colors.red['A400'] }
                },
                'Ocorreu um erro ao fazer o upload'
            )
        );
    };

    MultipleUploadWidget.prototype.renderUpload = function renderUpload() {
        var _this3 = this;

        var loading = this.state.loading;


        return _react2.default.createElement(
            'div',
            { style: { marginTop: '10px' } },
            _react2.default.createElement(_reactDropzone2.default, {
                ref: function ref(node) {
                    _this3.dropzoneRef = node;
                },
                onDrop: this.handleUploadFiles,
                style: { visibility: 'hidden' }
            }),
            _react2.default.createElement(
                _Button2.default,
                {
                    raised: true,
                    color: 'default',
                    onClick: function onClick() {
                        _this3.dropzoneRef.open();
                    },
                    disabled: loading
                },
                'Selecionar arquivos',
                _react2.default.createElement(_FileUpload2.default, null)
            )
        );
    };

    MultipleUploadWidget.prototype.render = function render() {
        var schema = this.props.schema;

        var label = schema.title;
        var _state = this.state,
            error = _state.error,
            accepted = _state.accepted;


        return _react2.default.createElement(
            'section',
            null,
            _react2.default.createElement(
                _Form.FormControl,
                { component: 'fieldset' },
                _react2.default.createElement(
                    _Form.FormLabel,
                    { component: 'legend' },
                    label
                )
            ),
            _react2.default.createElement(
                _Form.FormGroup,
                null,
                this.renderUpload(),
                error && this.renderError(),
                Boolean(accepted.length) && this.renderFileList()
            )
        );
    };

    return MultipleUploadWidget;
}(_react.Component);

MultipleUploadWidget.defaultProps = {
    formData: []
};

exports.default = MultipleUploadWidget;
module.exports = exports['default'];